==> Slicer3-3.0.2008-01-17-linux-x86_64.tar.gz: Slicer3-3.0.2008-01-17-linux-x86_64/lib/KWWidgets/KWWidgetsConfig.cmake <==
#-----------------------------------------------------------------------------
#
# KWWidgetsConfig.cmake - CMake configuration file for external projects.
#
# This file is configured by KWWidgets and used by the UseKWWidgets.cmake 
# module to load KWWidgets's settings for an external project.

# Compute the installation prefix from KWWidgets_DIR.
SET(KWWidgets_INSTALL_PREFIX "${KWWidgets_DIR}")
GET_FILENAME_COMPONENT(KWWidgets_INSTALL_PREFIX "${KWWidgets_INSTALL_PREFIX}" PATH)
GET_FILENAME_COMPONENT(KWWidgets_INSTALL_PREFIX "${KWWidgets_INSTALL_PREFIX}" PATH)

# The KWWidgets version number.
SET(KWWidgets_MAJOR_VERSION "1")
SET(KWWidgets_MINOR_VERSION "0")
SET(KWWidgets_PATCH_VERSION "0")

# The libraries.
SET(KWWidgets_LIBRARIES "KWWidgets")

# The list of available languages.
SET(KWWidgets_LANGUAGES "TCL")

# The CMake macros dir.
SET(KWWidgets_CMAKE_DIR "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/CMake")

# The configuration options.
SET(KWWidgets_BUILD_SHARED_LIBS "ON")
SET(KWWidgets_USE_HTML_HELP "")
SET(KWWidgets_USE_INTERNATIONALIZATION "OFF")
SET(KWWidgets_USE_INCR_TCL "OFF")
SET(KWWidgets_BUILD_VTK_WIDGETS "ON")

# Installation options.
SET(KWWidgets_INSTALL_DATA_DIR "/share/KWWidgets")

# The C and C++ flags added to the cmake-configured flags.
SET(KWWidgets_REQUIRED_C_FLAGS 
  "")
SET(KWWidgets_REQUIRED_CXX_FLAGS 
  "")
SET(KWWidgets_REQUIRED_EXE_LINKER_FLAGS 
  "")
SET(KWWidgets_REQUIRED_SHARED_LINKER_FLAGS 
  "")
SET(KWWidgets_REQUIRED_MODULE_LINKER_FLAGS 
  "")

# The "use" file.
SET(KWWidgets_USE_FILE "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/UseKWWidgets.cmake")

# The build settings file.
SET(KWWidgets_BUILD_SETTINGS_FILE "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/KWWidgetsBuildSettings.cmake")

# The library directories.
SET(KWWidgets_LIBRARY_DIRS "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets")

# The runtime directories.
# Note that if KWWidgets_CONFIGURATION_TYPES is set (see below) then
# these directories will be the parent directories under which there will
# be a directory of runtime binaries for each configuration type.
SET(KWWidgets_RUNTIME_DIRS "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets")

# The include directories.
SET(KWWidgets_INCLUDE_DIRS "${KWWidgets_INSTALL_PREFIX}/include/KWWidgets")

# The library dependencies file.
IF(NOT KWWidgets_NO_LIBRARY_DEPENDS AND
    EXISTS "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/KWWidgetsLibraryDepends.cmake")
  INCLUDE("${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/KWWidgetsLibraryDepends.cmake")
ENDIF(NOT KWWidgets_NO_LIBRARY_DEPENDS AND
  EXISTS "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/KWWidgetsLibraryDepends.cmake")

# The examples dir.
SET(KWWidgets_EXAMPLES_DIR "${KWWidgets_INSTALL_PREFIX}/share/KWWidgets/Examples")

# The templates dir.
SET(KWWidgets_TEMPLATES_DIR "${KWWidgets_INSTALL_PREFIX}/include/KWWidgets/Templates")

# The resources dir.
SET(KWWidgets_RESOURCES_DIR "${KWWidgets_INSTALL_PREFIX}/share/KWWidgets/Resources")

# The Tcl/Tk options.
SET(KWWidgets_TCL_PACKAGE_INDEX_DIR 
  "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/tcl")

# The Python options.
SET(KWWidgets_PYTHON_MODULE_DIR
  "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/../python2.4/site-packages")

# The Doxygen options.
SET(KWWidgets_DOXYGEN_DIR "${KWWidgets_INSTALL_PREFIX}")

# The VTK options.
SET(KWWidgets_VTK_DIR "/home/hayes/Slicer-3-0-release/Slicer-3-0/../Slicer3-lib/VTK-build")

# The gettext library. This is only defined for build dirs to help projects
# find the gettext library (it is safe to assume we are on the same machine;
# we could not guarantee that if we are building against an installed 
# KWWidgets though).
SET(GETTEXT_SEARCH_PATH ${GETTEXT_SEARCH_PATH} "")

# An install tree always provides one build configuration.
# A build tree may provide either one or multiple build
# configurations depending on the CMake generator used. Since
# this project can be used either from a build tree or an install tree it
# is useful for outside projects to know the configurations available.
# If this KWWidgetsConfig.cmake is in an install tree
# KWWidgets_CONFIGURATION_TYPES will be empty and KWWidgets_BUILD_TYPE
# will be set to the value of CMAKE_BUILD_TYPE used to build
# KWWidgets. If KWWidgetsConfig.cmake is in a build tree
# then KWWidgets_CONFIGURATION_TYPES and KWWidgets_BUILD_TYPE will
# have values matching CMAKE_CONFIGURATION_TYPES and CMAKE_BUILD_TYPE
# for that build tree (only one will ever be set).
SET(KWWidgets_CONFIGURATION_TYPES )
SET(KWWidgets_BUILD_TYPE Release)

==> Slicer3-3.0.2008-02-14-linux-x86_64.tar.gz: Slicer3-3.0.2008-02-14-linux-x86_64/lib/KWWidgets/KWWidgetsConfig.cmake <==
#-----------------------------------------------------------------------------
#
# KWWidgetsConfig.cmake - CMake configuration file for external projects.
#
# This file is configured by KWWidgets and used by the UseKWWidgets.cmake 
# module to load KWWidgets's settings for an external project.

# Compute the installation prefix from KWWidgets_DIR.
SET(KWWidgets_INSTALL_PREFIX "${KWWidgets_DIR}")
GET_FILENAME_COMPONENT(KWWidgets_INSTALL_PREFIX "${KWWidgets_INSTALL_PREFIX}" PATH)
GET_FILENAME_COMPONENT(KWWidgets_INSTALL_PREFIX "${KWWidgets_INSTALL_PREFIX}" PATH)

# The KWWidgets version number.
SET(KWWidgets_MAJOR_VERSION "1")
SET(KWWidgets_MINOR_VERSION "0")
SET(KWWidgets_PATCH_VERSION "0")

# The libraries.
SET(KWWidgets_LIBRARIES "KWWidgets")

# The list of available languages.
SET(KWWidgets_LANGUAGES "TCL")

# The CMake macros dir.
SET(KWWidgets_CMAKE_DIR "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/CMake")

# The configuration options.
SET(KWWidgets_BUILD_SHARED_LIBS "ON")
SET(KWWidgets_USE_HTML_HELP "")
SET(KWWidgets_USE_INTERNATIONALIZATION "OFF")
SET(KWWidgets_USE_INCR_TCL "OFF")
SET(KWWidgets_BUILD_VTK_WIDGETS "ON")

# Installation options.
SET(KWWidgets_INSTALL_DATA_DIR "/share/KWWidgets")

# The C and C++ flags added to the cmake-configured flags.
SET(KWWidgets_REQUIRED_C_FLAGS 
  "")
SET(KWWidgets_REQUIRED_CXX_FLAGS 
  "")
SET(KWWidgets_REQUIRED_EXE_LINKER_FLAGS 
  "")
SET(KWWidgets_REQUIRED_SHARED_LINKER_FLAGS 
  "")
SET(KWWidgets_REQUIRED_MODULE_LINKER_FLAGS 
  "")

# The "use" file.
SET(KWWidgets_USE_FILE "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/UseKWWidgets.cmake")

# The build settings file.
SET(KWWidgets_BUILD_SETTINGS_FILE "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/KWWidgetsBuildSettings.cmake")

# The library directories.
SET(KWWidgets_LIBRARY_DIRS "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets")

# The runtime directories.
# Note that if KWWidgets_CONFIGURATION_TYPES is set (see below) then
# these directories will be the parent directories under which there will
# be a directory of runtime binaries for each configuration type.
SET(KWWidgets_RUNTIME_DIRS "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets")

# The include directories.
SET(KWWidgets_INCLUDE_DIRS "${KWWidgets_INSTALL_PREFIX}/include/KWWidgets")

# The library dependencies file.
IF(NOT KWWidgets_NO_LIBRARY_DEPENDS AND
    EXISTS "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/KWWidgetsLibraryDepends.cmake")
  INCLUDE("${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/KWWidgetsLibraryDepends.cmake")
ENDIF(NOT KWWidgets_NO_LIBRARY_DEPENDS AND
  EXISTS "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/KWWidgetsLibraryDepends.cmake")

# The examples dir.
SET(KWWidgets_EXAMPLES_DIR "${KWWidgets_INSTALL_PREFIX}/share/KWWidgets/Examples")

# The templates dir.
SET(KWWidgets_TEMPLATES_DIR "${KWWidgets_INSTALL_PREFIX}/include/KWWidgets/Templates")

# The resources dir.
SET(KWWidgets_RESOURCES_DIR "${KWWidgets_INSTALL_PREFIX}/share/KWWidgets/Resources")

# The Tcl/Tk options.
SET(KWWidgets_TCL_PACKAGE_INDEX_DIR 
  "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/tcl")

# The Python options.
SET(KWWidgets_PYTHON_MODULE_DIR
  "${KWWidgets_INSTALL_PREFIX}/lib/KWWidgets/../python2.4/site-packages")

# The Doxygen options.
SET(KWWidgets_DOXYGEN_DIR "${KWWidgets_INSTALL_PREFIX}")

# The VTK options.
SET(KWWidgets_VTK_DIR "/home/hayes/Slicer-3-0-release/Slicer3/../Slicer3-lib/VTK-build")

# The gettext library. This is only defined for build dirs to help projects
# find the gettext library (it is safe to assume we are on the same machine;
# we could not guarantee that if we are building against an installed 
# KWWidgets though).
SET(GETTEXT_SEARCH_PATH ${GETTEXT_SEARCH_PATH} "")

# An install tree always provides one build configuration.
# A build tree may provide either one or multiple build
# configurations depending on the CMake generator used. Since
# this project can be used either from a build tree or an install tree it
# is useful for outside projects to know the configurations available.
# If this KWWidgetsConfig.cmake is in an install tree
# KWWidgets_CONFIGURATION_TYPES will be empty and KWWidgets_BUILD_TYPE
# will be set to the value of CMAKE_BUILD_TYPE used to build
# KWWidgets. If KWWidgetsConfig.cmake is in a build tree
# then KWWidgets_CONFIGURATION_TYPES and KWWidgets_BUILD_TYPE will
# have values matching CMAKE_CONFIGURATION_TYPES and CMAKE_BUILD_TYPE
# for that build tree (only one will ever be set).
SET(KWWidgets_CONFIGURATION_TYPES )
SET(KWWidgets_BUILD_TYPE Release)
